@@ -204,7 +204,9 @@ sub setup_element ($meta_root, $config_class, $element, $desc, $extra_info, $sup
         push @load_extra , q!match="^\d+(?i)[KMG]$"!;
     }
 
-    push @load, qw/type=list cargo/ if $element =~ /^Exec/ or $desc =~ /may be specified more than once/;
+    if ($element =~ /^(Exec|Condition)/ or $desc =~ /may be specified more than once/) {
+        push @load, qw/type=list cargo/;
+    }
 
     push @load, 'type=leaf', "value_type=$value_type";
 
