@@ -8,7 +8,10 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Systemd;
-$Config::Model::Systemd::VERSION = '0.232.4';
+$Config::Model::Systemd::VERSION = '0.232.5';
+use strict;
+use warnings;
+
 use 5.10.1;
 
 use Config::Model 2.096;
@@ -29,7 +32,7 @@ Config::Model::Systemd - Editor and validator for systemd configuration files
 
 =head1 VERSION
 
-version 0.232.4
+version 0.232.5
 
 =head1 SYNOPSIS
 
@@ -130,6 +133,12 @@ be supported.
 In case of issue, please log a bug on
 L<https://github.com/dod38fr/config-model-systemd/issues>.
 
+=head1 Contributors
+
+ Mohammad S Anwar
+
+Thanks for your contributions
+
 =head1 SEE ALSO
 
 =over
