@@ -13,7 +13,8 @@
       '.*',
       {
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'uniline',
+        'warn' => 'Unknown parameter'
       }
     ],
     'class_description' => 'A unit configuration file whose name ends in
@@ -22,54 +23,54 @@ network socket or a file system FIFO controlled and supervised by
 systemd, for socket-based activation.
 This man page lists the configuration options specific to
 this unit type. See
-L<systemd.unit(5)|"https://manpages.debian.org/cgi-bin/man.cgi?query=systemd.unit&sektion=5&manpath=Debian+unstable+sid">
+L<systemd.unit(5)>
 for the common options of all unit configuration files. The common
 configuration items are configured in the generic [Unit] and
 [Install] sections. The socket specific configuration options are
 configured in the [Socket] section.
 Additional options are listed in
-L<systemd.exec(5)|"https://manpages.debian.org/cgi-bin/man.cgi?query=systemd.exec&sektion=5&manpath=Debian+unstable+sid">,
+L<systemd.exec(5)>,
 which define the execution environment the
-ExecStartPre=, ExecStartPost=,
-ExecStopPre= and ExecStopPost=
+C<ExecStartPre>, C<ExecStartPost>,
+C<ExecStopPre> and C<ExecStopPost>
 commands are executed in, and in
-L<systemd.kill(5)|"https://manpages.debian.org/cgi-bin/man.cgi?query=systemd.kill&sektion=5&manpath=Debian+unstable+sid">,
+L<systemd.kill(5)>,
 which define the way the processes are terminated, and in
-L<systemd.resource-control(5)|"https://manpages.debian.org/cgi-bin/man.cgi?query=systemd.resource-control&sektion=5&manpath=Debian+unstable+sid">,
+L<systemd.resource-control(5)>,
 which configure resource control settings for the processes of the
 socket.
 For each socket file, a matching service file must exist,
 describing the service to start on incoming traffic on the socket
 (see
-L<systemd.service(5)|"https://manpages.debian.org/cgi-bin/man.cgi?query=systemd.service&sektion=5&manpath=Debian+unstable+sid">
+L<systemd.service(5)>
 for more information about .service files). The name of the
 .service unit is by default the same as the name of the .socket
-unit, but can be altered with the Service= option
+unit, but can be altered with the C<Service> option
 described below. Depending on the setting of the
-Accept= option described below, this .service
+C<Accept> option described below, this .service
 unit must either be named like the .socket unit, but with the
-suffix replaced, unless overridden with Service=;
+suffix replaced, unless overridden with C<Service>;
 or it must be a template unit named the same way. Example: a
 socket file foo.socket needs a matching
 service foo.service if
-Accept=false is set. If
-Accept=true is set, a service template file
+C<Accept=false> is set. If
+C<Accept=true> is set, a service template file
 foo@.service must exist from which services
 are instantiated for each incoming connection.
-Unless DefaultDependencies= in the C<[Unit]> section is set to
-false, socket units will implicitly have dependencies of type Requires= and
-After= on sysinit.target as well as dependencies of type
-Conflicts= and Before= on shutdown.target. These ensure
+Unless C<DefaultDependencies> in the C<[Unit]> section is set to
+C<false>, socket units will implicitly have dependencies of type C<Requires> and
+C<After> on sysinit.target as well as dependencies of type
+C<Conflicts> and C<Before> on shutdown.target. These ensure
 that socket units pull in basic system initialization, and are terminated cleanly prior to system shutdown. Only
 sockets involved with early boot or late system shutdown should disable this option.
-Socket units will have a Before=
+Socket units will have a C<Before>
 dependency on the service which they trigger added implicitly. No
-implicit WantedBy= or
-RequiredBy= dependency from the socket to the
+implicit C<WantedBy> or
+C<RequiredBy> dependency from the socket to the
 service is added. This means that the service may be started
 without the socket, in which case it must be able to open sockets
 by itself. To prevent this, an explicit
-Requires= dependency may be added.
+C<Requires> dependency may be added.
 Socket units may be used to implement on-demand starting of
 services, as well as parallelized starting of services. See the
 blog stories linked at the end for an introduction.
@@ -77,11 +78,11 @@ Note that the daemon software configured for socket
 activation with socket units needs to be able to accept sockets
 from systemd, either via systemd\'s native socket passing interface
 (see
-L<sd_listen_fds(3)|"https://manpages.debian.org/cgi-bin/man.cgi?query=sd_listen_fds&sektion=3&manpath=Debian+unstable+sid">
+L<sd_listen_fds(3)>
 for details) or via the traditional
-L<inetd(8)|"https://manpages.debian.org/cgi-bin/man.cgi?query=inetd&sektion=8&manpath=Debian+unstable+sid">-style
+L<inetd(8)>-style
 socket passing (i.e. sockets passed in via standard input and
-output, using StandardInput=socket in the
+output, using C<StandardInput=socket> in the
 service file).
 This configuration class was generated from systemd documentation.
 by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-man.pl>
@@ -98,18 +99,18 @@ by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-
           'value_type' => 'uniline'
         },
         'description' => 'Specifies an address to listen on for a stream
-(SOCK_STREAM), datagram
-(SOCK_DGRAM), or sequential packet
-(SOCK_SEQPACKET) socket, respectively.
+(C<SOCK_STREAM>), datagram
+(C<SOCK_DGRAM>), or sequential packet
+(C<SOCK_SEQPACKET>) socket, respectively.
 The address can be written in various formats:If the address starts with a slash
 (C</>), it is read as file system socket in
-the AF_UNIX socket family.If the address starts with an at symbol
+the C<AF_UNIX> socket family.If the address starts with an at symbol
 (C<@>), it is read as abstract namespace
-socket in the AF_UNIX family. The
+socket in the C<AF_UNIX> family. The
 C<@> is replaced with a
-NUL character before binding. For
+C<NUL> character before binding. For
 details, see
-L<unix(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>unix&C<sektion>7&C<manpath>Debian+unstable+sid">.If the address string is a single number, it is read as
+L<unix(7)>.If the address string is a single number, it is read as
 port number to listen on via IPv6. Depending on the value of
 C<BindIPv6Only> (see below) this might result
 in the service being available via both IPv6 and IPv4
@@ -120,12 +121,12 @@ address v.w.x.y on a port z.If the address string is a string in the format [x]:
 it is read as IPv6 address x on a port y. Note that this might
 make the service available via IPv4, too, depending on the
 C<BindIPv6Only> setting (see below).
-Note that SOCK_SEQPACKET (i.e.
+Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
-for AF_UNIX sockets.
-SOCK_STREAM (i.e.
+for C<AF_UNIX> sockets.
+C<SOCK_STREAM> (i.e.
 C<ListenStream>) when used for IP sockets
-refers to TCP sockets, SOCK_DGRAM (i.e.
+refers to TCP sockets, C<SOCK_DGRAM> (i.e.
 C<ListenDatagram>) to UDP.These options may be specified more than once, in which
 case incoming traffic on any of the sockets will trigger
 service activation, and all listed sockets will be passed to
@@ -153,18 +154,18 @@ below.',
           'value_type' => 'uniline'
         },
         'description' => 'Specifies an address to listen on for a stream
-(SOCK_STREAM), datagram
-(SOCK_DGRAM), or sequential packet
-(SOCK_SEQPACKET) socket, respectively.
+(C<SOCK_STREAM>), datagram
+(C<SOCK_DGRAM>), or sequential packet
+(C<SOCK_SEQPACKET>) socket, respectively.
 The address can be written in various formats:If the address starts with a slash
 (C</>), it is read as file system socket in
-the AF_UNIX socket family.If the address starts with an at symbol
+the C<AF_UNIX> socket family.If the address starts with an at symbol
 (C<@>), it is read as abstract namespace
-socket in the AF_UNIX family. The
+socket in the C<AF_UNIX> family. The
 C<@> is replaced with a
-NUL character before binding. For
+C<NUL> character before binding. For
 details, see
-L<unix(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>unix&C<sektion>7&C<manpath>Debian+unstable+sid">.If the address string is a single number, it is read as
+L<unix(7)>.If the address string is a single number, it is read as
 port number to listen on via IPv6. Depending on the value of
 C<BindIPv6Only> (see below) this might result
 in the service being available via both IPv6 and IPv4
@@ -175,12 +176,12 @@ address v.w.x.y on a port z.If the address string is a string in the format [x]:
 it is read as IPv6 address x on a port y. Note that this might
 make the service available via IPv4, too, depending on the
 C<BindIPv6Only> setting (see below).
-Note that SOCK_SEQPACKET (i.e.
+Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
-for AF_UNIX sockets.
-SOCK_STREAM (i.e.
+for C<AF_UNIX> sockets.
+C<SOCK_STREAM> (i.e.
 C<ListenStream>) when used for IP sockets
-refers to TCP sockets, SOCK_DGRAM (i.e.
+refers to TCP sockets, C<SOCK_DGRAM> (i.e.
 C<ListenDatagram>) to UDP.These options may be specified more than once, in which
 case incoming traffic on any of the sockets will trigger
 service activation, and all listed sockets will be passed to
@@ -208,18 +209,18 @@ below.',
           'value_type' => 'uniline'
         },
         'description' => 'Specifies an address to listen on for a stream
-(SOCK_STREAM), datagram
-(SOCK_DGRAM), or sequential packet
-(SOCK_SEQPACKET) socket, respectively.
+(C<SOCK_STREAM>), datagram
+(C<SOCK_DGRAM>), or sequential packet
+(C<SOCK_SEQPACKET>) socket, respectively.
 The address can be written in various formats:If the address starts with a slash
 (C</>), it is read as file system socket in
-the AF_UNIX socket family.If the address starts with an at symbol
+the C<AF_UNIX> socket family.If the address starts with an at symbol
 (C<@>), it is read as abstract namespace
-socket in the AF_UNIX family. The
+socket in the C<AF_UNIX> family. The
 C<@> is replaced with a
-NUL character before binding. For
+C<NUL> character before binding. For
 details, see
-L<unix(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>unix&C<sektion>7&C<manpath>Debian+unstable+sid">.If the address string is a single number, it is read as
+L<unix(7)>.If the address string is a single number, it is read as
 port number to listen on via IPv6. Depending on the value of
 C<BindIPv6Only> (see below) this might result
 in the service being available via both IPv6 and IPv4
@@ -230,12 +231,12 @@ address v.w.x.y on a port z.If the address string is a string in the format [x]:
 it is read as IPv6 address x on a port y. Note that this might
 make the service available via IPv4, too, depending on the
 C<BindIPv6Only> setting (see below).
-Note that SOCK_SEQPACKET (i.e.
+Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
-for AF_UNIX sockets.
-SOCK_STREAM (i.e.
+for C<AF_UNIX> sockets.
+C<SOCK_STREAM> (i.e.
 C<ListenStream>) when used for IP sockets
-refers to TCP sockets, SOCK_DGRAM (i.e.
+refers to TCP sockets, C<SOCK_DGRAM> (i.e.
 C<ListenDatagram>) to UDP.These options may be specified more than once, in which
 case incoming traffic on any of the sockets will trigger
 service activation, and all listed sockets will be passed to
@@ -282,8 +283,8 @@ open character device nodes as well as special files in
       {
         'description' => 'Specifies a Netlink family to create a socket
 for to listen on. This expects a short string referring to the
-AF_NETLINK family name (such as
-audit or kobject-uevent)
+C<AF_NETLINK> family name (such as
+C<audit> or C<kobject-uevent>)
 as argument, optionally suffixed by a whitespace followed by a
 multicast group integer. Behavior otherwise is very similar to
 the C<ListenDatagram> directive
@@ -305,10 +306,10 @@ can be inherited between processes.',
       'ListenUSBFunction',
       {
         'description' => 'Specifies a USB
-FunctionFS endpoint location to listen on, for
+FunctionFS endpoints location to listen on, for
 implementation of USB gadget functions. This expects an
-absolute file system path as the argument. Behavior otherwise
-is very similar to the C<ListenFIFO>
+absolute file system path of functionfs mount point as the argument.
+Behavior otherwise is very similar to the C<ListenFIFO>
 directive above. Use this to open the FunctionFS endpoint
 ep0. When using this option, the
 activated service has to have the
@@ -320,28 +321,28 @@ C<USBFunctionStrings> options set.
       },
       'SocketProtocol',
       {
-        'description' => 'Takes a one of udplite
-or sctp. Specifies a socket protocol
-(IPPROTO_UDPLITE) UDP-Lite
-(IPPROTO_SCTP) SCTP socket respectively. ',
+        'description' => 'Takes a one of C<udplite>
+or C<sctp>. Specifies a socket protocol
+(C<IPPROTO_UDPLITE>) UDP-Lite
+(C<IPPROTO_SCTP>) SCTP socket respectively. ',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'BindIPv6Only',
       {
-        'description' => 'Takes a one of default,
-both or ipv6-only. Controls
+        'description' => 'Takes a one of C<default>,
+C<both> or C<ipv6-only>. Controls
 the IPV6_V6ONLY socket option (see
-L<ipv6(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>ipv6&C<sektion>7&C<manpath>Debian+unstable+sid">
-for details). If both, IPv6 sockets bound
+L<ipv6(7)>
+for details). If C<both>, IPv6 sockets bound
 will be accessible via both IPv4 and IPv6. If
-ipv6-only, they will be accessible via IPv6
-only. If default (which is the default,
+C<ipv6-only>, they will be accessible via IPv6
+only. If C<default> (which is the default,
 surprise!), the system wide default setting is used, as
 controlled by
 /proc/sys/net/ipv6/bindv6only, which in
 turn defaults to the equivalent of
-both.',
+C<both>.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -351,7 +352,7 @@ both.',
 the number of connections to queue that have not been accepted
 yet. This setting matters only for stream and sequential
 packet sockets. See
-L<listen(2)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>listen&C<sektion>2&C<manpath>Debian+unstable+sid">
+L<listen(2)>
 for details. Defaults to SOMAXCONN (128).',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -361,10 +362,10 @@ for details. Defaults to SOMAXCONN (128).',
         'description' => 'Specifies a network interface name to bind
 this socket to. If set, traffic will only be accepted from the
 specified network interfaces. This controls the
-SO_BINDTODEVICE socket option (see L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+SO_BINDTODEVICE socket option (see L<socket(7)>
 for details). If this option is used, an automatic dependency
 from this socket unit on the network interface device unit
-(L<systemd.device(5)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>systemd.device&C<sektion>5&C<manpath>Debian+unstable+sid">
+(L<systemd.device(5)>
 is created. Note that setting this parameter might result in
 additional dependencies to be added to the unit (see
 above).',
@@ -423,25 +424,25 @@ sockets themselves are passed to the started service unit, and
 only one service unit is spawned for all connections (also see
 above). This value is ignored for datagram sockets and FIFOs
 where a single service unit unconditionally handles all
-incoming traffic. Defaults to false. For
+incoming traffic. Defaults to C<false>. For
 performance reasons, it is recommended to write new daemons
 only in a way that is suitable for
-C<Accept>false. A daemon listening on an
-AF_UNIX socket may, but does not need to,
+C<Accept=false>. A daemon listening on an
+C<AF_UNIX> socket may, but does not need to,
 call
-L<close(2)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>close&C<sektion>2&C<manpath>Debian+unstable+sid">
+L<close(2)>
 on the received socket before exiting. However, it must not
 unlink the socket from a file system. It should not invoke
-L<shutdown(2)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>shutdown&C<sektion>2&C<manpath>Debian+unstable+sid">
-on sockets it got with C<Accept>false, but it
+L<shutdown(2)>
+on sockets it got with C<Accept=false>, but it
 may do so for sockets it got with
-C<Accept>true set. Setting
-C<Accept>true is mostly useful to allow
+C<Accept=true> set. Setting
+C<Accept=true> is mostly useful to allow
 daemons designed for usage with
-L<inetd(8)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>inetd&C<sektion>8&C<manpath>Debian+unstable+sid">
+L<inetd(8)>
 to work unmodified with systemd socket
-activation.For IPv4 and IPv6 connections, the REMOTE_ADDR
-environment variable will contain the remote IP address, and REMOTE_PORT
+activation.For IPv4 and IPv6 connections, the C<REMOTE_ADDR>
+environment variable will contain the remote IP address, and C<REMOTE_PORT>
 will contain the remote port. This is the same as the format used by CGI.
 For SOCK_RAW, the port is the IP protocol.',
         'type' => 'leaf',
@@ -468,15 +469,23 @@ false, in read-only mode. Defaults to false.',
       {
         'description' => 'The maximum number of connections to
 simultaneously run services instances for, when
-C<Accept>true is set. If more concurrent
+C<Accept=true> is set. If more concurrent
 connections are coming in, they will be refused until at least
 one existing connection is terminated. This setting has no
 effect on sockets configured with
-C<Accept>false or datagram sockets. Defaults to
+C<Accept=false> or datagram sockets. Defaults to
 64.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
+      'MaxConnectionsPerSource',
+      {
+        'description' => 'The maximum number of connections for a service per source IP address.
+This is very similar to the C<MaxConnections> directive
+above. Disabled by default.',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
       'KeepAlive',
       {
         'description' => 'Takes a boolean argument. If true, the TCP/IP
@@ -485,10 +494,10 @@ the configuration of
 /proc/sys/net/ipv4/tcp_keepalive_time)
 for all TCP streams accepted on this socket. This controls the
 SO_KEEPALIVE socket option (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 and the TCP
 Keepalive HOWTO for details.) Defaults to
-false.',
+C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -501,7 +510,7 @@ false.',
         'description' => 'Takes time (in seconds) as argument. The connection needs to remain
 idle before TCP starts sending keepalive probes. This controls the TCP_KEEPIDLE
 socket option (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 and the TCP
 Keepalive HOWTO for details.)
 Defaults value is 7200 seconds (2 hours).',
@@ -514,7 +523,7 @@ Defaults value is 7200 seconds (2 hours).',
 individual keepalive probes, if the socket option SO_KEEPALIVE
 has been set on this socket. This controls
 the TCP_KEEPINTVL socket option (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 and the TCP
 Keepalive HOWTO for details.) Defaults value is 75
 seconds.',
@@ -527,7 +536,7 @@ seconds.',
 unacknowledged probes to send before considering the
 connection dead and notifying the application layer. This
 controls the TCP_KEEPCNT socket option (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 and the TCP
 Keepalive HOWTO for details.) Defaults value is
 9.',
@@ -540,8 +549,8 @@ Keepalive HOWTO for details.) Defaults value is
 algorithm works by combining a number of small outgoing
 messages, and sending them all at once. This controls the
 TCP_NODELAY socket option (see
-L<tcp(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>tcp&C<sektion>7&C<manpath>Debian+unstable+sid">
-Defaults to false.',
+L<tcp(7)>
+Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -554,7 +563,7 @@ Defaults to false.',
         'description' => 'Takes an integer argument controlling the
 priority for all traffic sent from this socket. This controls
 the SO_PRIORITY socket option (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 for details.).',
         'type' => 'leaf',
         'value_type' => 'integer'
@@ -565,19 +574,19 @@ for details.).',
 the listening process will be awakened only when data arrives
 on the socket, and not immediately when connection is
 established. When this option is set, the
-TCP_DEFER_ACCEPT socket option will be
+C<TCP_DEFER_ACCEPT> socket option will be
 used (see
-L<tcp(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>tcp&C<sektion>7&C<manpath>Debian+unstable+sid">),
+L<tcp(7)>),
 and the kernel will ignore initial ACK packets without any
 data. The argument specifies the approximate amount of time
 the kernel should wait for incoming data before falling back
-to the normal behavior of honouring empty ACK packets. This
+to the normal behavior of honoring empty ACK packets. This
 option is beneficial for protocols where the client sends the
 data first (e.g. HTTP, in contrast to SMTP), because the
 server process will not be woken up unnecessarily before it
 can take any action.
 If the client also uses the
-TCP_DEFER_ACCEPT option, the latency of
+C<TCP_DEFER_ACCEPT> option, the latency of
 the initial connection may be reduced, because the kernel will
 send data in the final packet establishing the connection (the
 third packet in the "three-way handshake").Disabled by default.',
@@ -589,32 +598,34 @@ third packet in the "three-way handshake").Disabled by default.',
         'description' => 'Takes an integer argument controlling the
 receive or send buffer sizes of this socket, respectively.
 This controls the SO_RCVBUF and SO_SNDBUF socket options (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 for details.). The usual suffixes K, M, G are supported and
 are understood to the base of 1024.',
+        'match' => '^\\d+(?i)[KMG]$',
         'type' => 'leaf',
-        'value_type' => 'integer'
+        'value_type' => 'uniline'
       },
       'SendBuffer',
       {
         'description' => 'Takes an integer argument controlling the
 receive or send buffer sizes of this socket, respectively.
 This controls the SO_RCVBUF and SO_SNDBUF socket options (see
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 for details.). The usual suffixes K, M, G are supported and
 are understood to the base of 1024.',
+        'match' => '^\\d+(?i)[KMG]$',
         'type' => 'leaf',
-        'value_type' => 'integer'
+        'value_type' => 'uniline'
       },
       'IPTOS',
       {
         'description' => 'Takes an integer argument controlling the IP
 Type-Of-Service field for packets generated from this socket.
 This controls the IP_TOS socket option (see
-L<ip(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>ip&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<ip(7)>
 for details.). Either a numeric string or one of
-low-delay, throughput,
-reliability or low-cost may
+C<low-delay>, C<throughput>,
+C<reliability> or C<low-cost> may
 be specified.',
         'type' => 'leaf',
         'value_type' => 'integer'
@@ -625,9 +636,9 @@ be specified.',
 Time-To-Live/IPv6 Hop-Count field for packets generated from
 this socket. This sets the IP_TTL/IPV6_UNICAST_HOPS socket
 options (see
-L<ip(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>ip&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<ip(7)>
 and
-L<ipv6(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>ipv6&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<ipv6(7)>
 for details.)',
         'type' => 'leaf',
         'value_type' => 'integer'
@@ -638,7 +649,7 @@ for details.)',
 mark of packets generated by this socket. This can be used in
 the firewall logic to filter packets from this socket. This
 sets the SO_MARK socket option. See
-L<iptables(8)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>iptables&C<sektion>8&C<manpath>Debian+unstable+sid">
+L<iptables(8)>
 for details.',
         'type' => 'leaf',
         'value_type' => 'integer'
@@ -647,10 +658,10 @@ for details.',
       {
         'description' => 'Takes a boolean value. If true, allows
 multiple
-L<bind(2)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>bind&C<sektion>2&C<manpath>Debian+unstable+sid">s
+L<bind(2)>s
 to this TCP or UDP port. This controls the SO_REUSEPORT socket
 option. See
-L<socket(7)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>socket&C<sektion>7&C<manpath>Debian+unstable+sid">
+L<socket(7)>
 for details.',
         'type' => 'leaf',
         'value_type' => 'boolean',
@@ -724,7 +735,7 @@ C<false>. ',
       {
         'description' => 'Takes a size in bytes. Controls the pipe
 buffer size of FIFOs configured in this socket unit. See
-L<fcntl(2)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>fcntl&C<sektion>2&C<manpath>Debian+unstable+sid">
+L<fcntl(2)>
 for details. The usual suffixes K, M, G are supported and are
 understood to the base of 1024.',
         'type' => 'leaf',
@@ -736,7 +747,7 @@ understood to the base of 1024.',
 control the mq_maxmsg field or the mq_msgsize field,
 respectively, when creating the message queue. Note that
 either none or both of these variables need to be set. See
-L<mq_setattr(3)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>mq_setattr&C<sektion>3&C<manpath>Debian+unstable+sid">
+L<mq_setattr(3)>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -750,7 +761,7 @@ those IP addresses are successfully configured on a network
 interface. This sets the IP_FREEBIND socket option. For
 robustness reasons it is recommended to use this option
 whenever you bind a socket to a specific IP address. Defaults
-to false.',
+to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -762,7 +773,7 @@ to false.',
       {
         'description' => 'Takes a boolean value. Controls the
 IP_TRANSPARENT socket option. Defaults to
-false.',
+C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -775,7 +786,7 @@ false.',
         'description' => 'Takes a boolean value. This controls the
 SO_BROADCAST socket option, which allows broadcast datagrams
 to be sent from this socket. Defaults to
-false.',
+C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -787,9 +798,9 @@ false.',
       {
         'description' => 'Takes a boolean value. This controls the
 SO_PASSCRED socket option, which allows
-AF_UNIX sockets to receive the
+C<AF_UNIX> sockets to receive the
 credentials of the sending process in an ancillary message.
-Defaults to false.',
+Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -801,9 +812,9 @@ Defaults to false.',
       {
         'description' => 'Takes a boolean value. This controls the
 SO_PASSSEC socket option, which allows
-AF_UNIX sockets to receive the security
+C<AF_UNIX> sockets to receive the security
 context of the sending process in an ancillary message.
-Defaults to false.',
+Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -891,16 +902,16 @@ C<ExecStopPost> to finish. If a command does
 not exit within the configured time, the socket will be
 considered failed and be shut down again. All commands still
 running will be terminated forcibly via
-SIGTERM, and after another delay of this
-time with SIGKILL. (See
+C<SIGTERM>, and after another delay of this
+time with C<SIGKILL>. (See
 C<KillMode> in
-L<systemd.kill(5)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>systemd.kill&C<sektion>5&C<manpath>Debian+unstable+sid">.)
+L<systemd.kill(5)>.)
 Takes a unit-less value in seconds, or a time span value such
 as "5min 20s". Pass C<0> to disable the
 timeout logic. Defaults to
 C<DefaultTimeoutStartSec> from the manager
 configuration file (see
-L<systemd-system.conf(5)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>systemd-system.conf&C<sektion>5&C<manpath>Debian+unstable+sid">).
+L<systemd-system.conf(5)>).
 ',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -909,7 +920,7 @@ L<systemd-system.conf(5)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>sy
       {
         'description' => 'Specifies the service unit name to activate on
 incoming traffic. This setting is only allowed for sockets
-with C<Accept>no. It defaults to the service
+with C<Accept=no>. It defaults to the service
 that bears the same name as the socket (with the suffix
 replaced). In most cases, it should not be necessary to use
 this option. Note that setting this parameter might result in
@@ -956,7 +967,7 @@ list.',
 socket unit encapsulates. This is useful to help activated
 services identify specific file descriptors, if multiple fds
 are passed. Services may use the
-L<sd_listen_fds_with_names(3)|"https://manpages.debian.org/cgi-bin/man.cgi?C<query>sd_listen_fds_with_names&C<sektion>3&C<manpath>Debian+unstable+sid">
+L<sd_listen_fds_with_names(3)>
 call to acquire the names configured for the received file
 descriptors. Names may contain any ASCII character, but must
 exclude control characters and C<:>, and must
@@ -973,10 +984,10 @@ suffix.',
 interval. The C<TriggerLimitIntervalSec> may be used to configure the length of the time
 interval in the usual time units C<us>, C<ms>, C<s>,
 C<min>, C<h>, \x{2026} and defaults to 2s (See
-L<systemd.time(7)|\"https://manpages.debian.org/cgi-bin/man.cgi?C<query>systemd.time&C<sektion>7&C<manpath>Debian+unstable+sid\"> for details on
+L<systemd.time(7)> for details on
 the various time units understood). The C<TriggerLimitBurst> setting takes a positive integer
 value and specifies the number of permitted activations per time interval, and defaults to 200 for
-C<Accept>yes sockets (thus by default permitting 200 activations per 2s), and 20 otherwise (20
+C<Accept=yes> sockets (thus by default permitting 200 activations per 2s), and 20 otherwise (20
 activations per 2s). Set either to 0 to disable any form of trigger rate limiting. If the limit is hit, the
 socket unit is placed into a failure mode, and will not be connectible anymore until restarted. Note that this
 limit is enforced before the service activation is enqueued.",
@@ -989,10 +1000,10 @@ limit is enforced before the service activation is enqueued.",
 interval. The C<TriggerLimitIntervalSec> may be used to configure the length of the time
 interval in the usual time units C<us>, C<ms>, C<s>,
 C<min>, C<h>, \x{2026} and defaults to 2s (See
-L<systemd.time(7)|\"https://manpages.debian.org/cgi-bin/man.cgi?C<query>systemd.time&C<sektion>7&C<manpath>Debian+unstable+sid\"> for details on
+L<systemd.time(7)> for details on
 the various time units understood). The C<TriggerLimitBurst> setting takes a positive integer
 value and specifies the number of permitted activations per time interval, and defaults to 200 for
-C<Accept>yes sockets (thus by default permitting 200 activations per 2s), and 20 otherwise (20
+C<Accept=yes> sockets (thus by default permitting 200 activations per 2s), and 20 otherwise (20
 activations per 2s). Set either to 0 to disable any form of trigger rate limiting. If the limit is hit, the
 socket unit is placed into a failure mode, and will not be connectible anymore until restarted. Note that this
 limit is enforced before the service activation is enqueued.",
