@@ -13,7 +13,8 @@
       '.*',
       {
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'uniline',
+        'warn' => 'Unknown parameter'
       }
     ],
     'class_description' => "A unit configuration file encodes information about a
@@ -772,35 +773,39 @@ works just like the optional argument to systemctl reboot command.',
       },
       'ConditionArchitecture',
       {
-        'choice' => [
-          'x86',
-          'x86-64',
-          'ppc',
-          'ppc-le',
-          'ppc64',
-          'ppc64-le',
-          'ia64',
-          'parisc',
-          'parisc64',
-          's390',
-          's390x',
-          'sparc',
-          'sparc64',
-          'mips',
-          'mips-le',
-          'mips64',
-          'mips64-le',
-          'alpha',
-          'arm',
-          'arm-be',
-          'arm64',
-          'arm64-be',
-          'sh',
-          'sh64',
-          'm86k',
-          'tilegx',
-          'cris'
-        ],
+        'cargo' => {
+          'choice' => [
+            'x86',
+            'x86-64',
+            'ppc',
+            'ppc-le',
+            'ppc64',
+            'ppc64-le',
+            'ia64',
+            'parisc',
+            'parisc64',
+            's390',
+            's390x',
+            'sparc',
+            'sparc64',
+            'mips',
+            'mips-le',
+            'mips64',
+            'mips64-le',
+            'alpha',
+            'arm',
+            'arm-be',
+            'arm64',
+            'arm64-be',
+            'sh',
+            'sh64',
+            'm86k',
+            'tilegx',
+            'cris'
+          ],
+          'type' => 'leaf',
+          'value_type' => 'enum'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -866,11 +871,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'enum'
+        'type' => 'list'
       },
       'ConditionVirtualization',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -926,11 +934,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionHost',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -966,11 +977,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionKernelCommandLine',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1005,11 +1019,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionSecurity',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1044,11 +1061,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionCapability',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1083,11 +1103,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionACPower',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1123,11 +1146,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionNeedsUpdate',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1169,11 +1195,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionFirstBoot',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1206,11 +1235,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionPathExists',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1244,11 +1276,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionPathExistsGlob',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1278,11 +1313,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionPathIsDirectory',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1311,11 +1349,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionPathIsSymbolicLink',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1345,11 +1386,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionPathIsMountPoint',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1378,11 +1422,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionPathIsReadWrite',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1412,11 +1459,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionDirectoryNotEmpty',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1446,11 +1496,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionFileNotEmpty',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1480,11 +1533,14 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ConditionFileIsExecutable',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Before starting a unit, verify that the specified condition is true. If it is not true, the
 starting of the unit will be (mostly silently) skipped, however all ordering dependencies of it are still
 respected. A failing condition will not result in the unit being moved into a failure state. The condition is
@@ -1514,8 +1570,7 @@ checks follow symlinks. If any of these options is assigned
 the empty string, the list of conditions is reset completely,
 all previous condition settings (of any kind) will have no
 effect.",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'AssertArchitecture',
       {
